@@ -119,7 +119,7 @@ Returns the process associated with the connection."
 	(coding-system-for-write 'binary)
 	process)
     (save-excursion
-      (set-buffer (get-buffer-create (concat " trace of POP session to %s"
+      (set-buffer (get-buffer-create (concat " trace of POP session to "
 					     mailhost)))
       (erase-buffer)
       (setq pop3-read-point (point-min))
